Werkzeug Documentation

# Werkzeug

# Installation

Werkzeug requires at least Python 2.4 to work correctly.

## Installing a released version

### As a Python egg (via easy_install)

You can install the most recent Werkzeug version using easy_install:

    sudo easy_install Werkzeug

This will install a Werkzeug egg in your Python installation’s site-packages directory.

### From the tarball release

1. Download the most recent tarball from the download page.
2. Unpack the tarball.
3. `sudo python setup.py install`

Note that the last command will automatically download and install setuptools if you don’t already have it installed. This requires a working Internet connection.

This will install Werkzeug into your Python installation’s site-packages directory.

## Installing the development version

### If you want to play around with the code

1. Install Mercurial
2. `hg clone http://dev.pocoo.org/hg/werkzeug-main werkzeug`
3. `cd werkzeug`
4. `ln -s werkzeug /usr/lib/python2.X/site-packages`

### If you just want the latest features and use them

    sudo easy_install Werkzeug==dev

This will install a Werkzeug egg containing the latest mercurial tip in your Python installation’s site-packages directory. Every time the command is run, the sources are updated from the mercurial repository.

However we strongly recommend cloning the repository and linking it instead as explained in the step before.